RemoteEmbeddingGenerator

Struct RemoteEmbeddingGenerator 

pub struct RemoteEmbeddingGenerator {
    pub model_type: EmbeddingModelType,
    pub api_url: String,
    pub api_key: Option<String>,
}

Fields

model_type: EmbeddingModelTypeapi_url: Stringapi_key: Option<String>

Implementations

Source

impl RemoteEmbeddingGenerator

pub fn new( model_type: EmbeddingModelType, api_url: &str, api_key: Option<String>, ) -> RemoteEmbeddingGenerator

Create a RemoteEmbeddingGenerator

pub fn new_default() -> RemoteEmbeddingGenerator

Create a RemoteEmbeddingGenerator that uses the default model and server

pub fn new_default_local() -> RemoteEmbeddingGenerator

Create a RemoteEmbeddingGenerator that uses the default model and server

pub async fn generate_embedding_ollama( &self, input_string: String, model: String, ) -> Result<Vec<f32>, ZooEmbeddingError>

Generates embeddings using Hugging Face’s Text Embedding Interface server pub async fn generate_embedding_open_ai(&self, input_string: &str, id: &str) -> Result<Embedding, VRError> {

pub async fn generate_embedding_tei( &self, input_strings: Vec<String>, ) -> Result<Vec<Vec<f32>>, ZooEmbeddingError>

Generates embeddings using Hugging Face’s Text Embedding Interface server

pub async fn generate_embedding_open_ai( &self, input_string: &str, ) -> Result<Vec<f32>, ZooEmbeddingError>

Generate an Embedding for an input string by using the external OpenAI-matching API.